Drive

Struct Drive 

pub struct Drive {
    pub lb: Lb,
    pub root: Uuid,
    pub data: Arc<Mutex<HashMap<UuidFileHandle, FileEntry>>>,
}

Fields

lb: Lbroot: Uuid

must be not-nil before NFSFIlesSystem is mounted

data: Arc<Mutex<HashMap<UuidFileHandle, FileEntry>>>

probably this doesn’t need to have a global lock, but interactions here are generally speedy, and for now we’ll go for robustness over performance. Hopefully this accomplishes that and not deadlock. TBD.

this is stored in memory as it’s own entity and not stored in core for two reasons:

  1. size computations are expensive in core
  2. nfs needs to update timestamps to specified values
  3. nfs models properties we don’t, like file permission bits

Implementations

Source

impl Drive

pub async fn prepare_caches(&self)

pub async fn sync(&self)

Source

impl Drive

pub async fn init() -> Self

pub async fn import() -> CliResult<()>

pub async fn mount() -> CliResult<()>

pub fn progress() -> Option<Box<dyn Fn(SyncProgress) + Send>>