pub struct Drive {
pub lb: Lb,
pub root: Uuid,
pub data: Arc<Mutex<HashMap<fileid3, FileEntry>>>,
}Fields
lb: Lbroot: Uuidmust be not-nil before NFSFIlesSystem is mounted
data: Arc<Mutex<HashMap<fileid3, FileEntry>>>probably this doesn’t need to have a global lock, but interactions here are generally speedy, and for now we’ll go for robustness over performance. Hopefully this accomplishes that and not deadlock. TBD.
this is stored in memory as it’s own entity and not stored in core for two reasons:
- size computations are expensive in core
- nfs needs to update timestamps to specified values
- nfs models properties we don’t, like file permission bits
Implementations